import QtQuick 2.0
import Sailfish.Silica 1.0
import Nemo.Configuration 1.0

Page {
    id: page
    allowedOrientations: Orientation.All
    Component.onCompleted: {
        var value, sign = 1
        if (pulleyLocations.value <= 0) {
            toolBar.checked = true
            sign = -1
        } else {
            toolBar.checked = false
        }
        value = sign * pulleyLocations.value

        if (value === 0 || value === 2) {
            bottomMenu.checked = false
        }
        if (value === 0 || value === 1) {
            topMenu.checked = false
        }

        settingUp = false
    }

    property bool settingUp: true

    ConfigurationValue {
        id: pulleyLocations
        key: "/apps/patchmanager/browser-tabs-pulley-menu/locations"
        defaultValue: 3 // 1 - bottom, 2 - top, 3 - top & bottom, negative values don't hide the tool bar
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: column.height

        VerticalScrollDecorator{}

        Column {
            id: column
            width: parent.width
            spacing: Theme.paddingMedium

            PageHeader {
                title: qsTr("Pulley menus on the tabs view")
            }

            Label {
                text: qsTr("Adds PullDown & PushUp menus on the tabs view of the browser and removes the tool bar.")
                color: Theme.highlightColor
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width - 2*x
                x: Theme.horizontalPageMargin
            }

            TextSwitch {
                id: bottomMenu
                text: checked? qsTr("PushUpMenu visible.") : qsTr("PushUpMenu hidden.")
                checked: true
				onCheckedChanged: {
                    if (!checked && !topMenu.checked) {
                        toolBar.checked = true
                    }
                    if (!settingUp) storeLocation()
				}
            }

            TextSwitch {
                id: topMenu
                text: checked? qsTr("PullDownMenu visible.") : qsTr("PullDownMenu hidden.")
                checked: true
                onCheckedChanged: {
                    if (!checked && !bottomMenu.checked) {
                        toolBar.checked = true
                    }
                    if (!settingUp) storeLocation()
                }
            }

            TextSwitch {
                id: toolBar
                text: checked? qsTr("ToolBar visible.") : qsTr("ToolBar hidden.")
                checked: false
                onCheckedChanged: {
                    if (!checked && !bottomMenu.checked && !topMenu.checked) {
                        bottomMenu.checked = true
                        topMenu.checked = true
                    }
                    if (!settingUp) storeLocation()
                }

            }

            Label {
                text: qsTr("Modifies %1 in %2.").arg("TabView.qml").arg("/usr/share/sailfish-browser/pages/components")
                color: Theme.highlightColor
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width - 2*x
                x: Theme.horizontalPageMargin
            }
        }
    }

    function storeLocation() {
        var sign, value = 0;

        if (toolBar.checked) {
            sign = -1;
        } else {
            sign = 1;
        }

        if (bottomMenu.checked) {
            value = 1;
        } else {
            value = 0;
        }

        if (topMenu.checked) {
            value += 2;
        }

        pulleyLocations.value = value * sign;
        pulleyLocations.sync();

        return;
    }
}
